@@ -7,8 +7,10 @@ use Data::Dumper;
 use RPi::WiringPi;
 use RPi::WiringPi::Constant qw(:all);
 
-my $pi = RPi::WiringPi->new;
-$pi->setup;
+my $continue = 1;
+$SIG{INT} = sub { $continue = 0; };
+
+my $pi = RPi::WiringPi->new(setup => 'gpio');
 
 my $lcd = $pi->lcd;
 
@@ -16,12 +18,12 @@ my %args = (
     cols => 16,
     rows => 2,
     bits => 4,
-    rs => 6,
-    strb => 5,
-    d0 => 4,
-    d1 => 2, 
-    d2 => 1, 
-    d3 => 3,
+    rs => 27,
+    strb => 26,
+    d0 => 11,
+    d1 => 12, 
+    d2 => 13, 
+    d3 => 14,
     d4 => 0,
     d5 => 0, 
     d6 => 0, 
@@ -30,25 +32,20 @@ my %args = (
 
 $lcd->init(%args);
 
-#$lcd->cursor(0);
-#$lcd->cursor_blink(0);
-
 $lcd->position(0, 0);
 $lcd->print("stevieb");
 
-my $continue = 1;
-$SIG{INT} = sub { $continue = 0; };
+my $pin = $pi->pin(9);
 
 while ($continue){
+    $pin->mode(OUTPUT);
+    $pin->write(HIGH);
     $lcd->position(0, 1);
     my ($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst) = localtime();
 
-    if ($min % 2 = 0){
-        $lcd->print("  beer time!");
-    }
-    else {
-        $lcd->print("$hour:$min");
-    }
+    $lcd->print("$hour:$min");
+    sleep 1;
+    $pin->write(LOW); 
     sleep 1;
 }
 $lcd->clear;
