@@ -2,7 +2,6 @@ package RPi::WiringPi::Interrupt;
 
 use strict;
 use warnings;
-use threads;
 
 use parent 'WiringPi::API';
 use parent 'RPi::WiringPi::Util';
@@ -10,32 +9,32 @@ use parent 'RPi::WiringPi::Util';
 use Config;
 use RPi::WiringPi::Constant qw(:all);
 
-our $VERSION = '0.99_03';
+our $VERSION = '0.99_05';
 
 my $interrupts = {};
 
 sub new {
-    $Config{useithreads}
-      or die "Perl is not compiled with threads, Interrupts not available\n";
     return bless {}, shift;
 }
 sub set {
     my ($self, $pin, $edge, $callback) = @_;
 
-    my $gpio = $self->pin_to_gpio($pin);
+    # unset the interrupt if we're changing
+    # it
 
-    $interrupts->{$gpio}{$edge}{value} = $edge;
-    $interrupts->{$gpio}{$edge}{callback} = $callback;
-    $interrupts->set_interrupt($gpio, $edge, $callback);
+    if (defined $interrupts->{$pin}{edge}){
+        $self->unset($pin);
+    }
+
+    $interrupts->{$pin}{edge} = $edge;
+
+    $self->set_interrupt($pin, $edge, $callback);
 }
 sub unset {
     my ($self, $pin) = @_;
     if ($pin eq 'all'){
-        for my $pin (keys %$interrupts){
-            my $gpio = $self->pin_to_gpio($pin);
-            for (keys %{ $interrupts->{$gpio} }){
-                $interrupts->unset($gpio);
-            }
+        for (keys %$interrupts){
+            $self->unset($_);
         }
     }
     else {
