@@ -4,9 +4,12 @@ use strict;
 use warnings;
 
 use parent 'WiringPi::API';
+use parent 'RPi::WiringPi::Util';
+
+use RPi::WiringPi::Constant qw(:all);
 use RPi::WiringPi::Interrupt;
 
-our $VERSION = '0.99_03';
+our $VERSION = '0.99_05';
 
 sub new {
     my ($class, $pin) = @_;
@@ -18,6 +21,10 @@ sub new {
     my $self = bless {}, $class;
 
     $self->{pin} = $pin;
+
+    if ($self->pin_scheme == RPI_MODE_GPIO_SYS){
+        $self->export_pin($pin->num);
+    }
     return $self;
 }
 sub mode {
@@ -27,11 +34,24 @@ sub mode {
         return $self->get_alt($self->num);
     }
     if ($mode != 0 && $mode != 1 && $mode != 2 && $mode != 3){
-        die "Core::pin_mode() mode param must be either 0 (input), 1 " .
+        die "mode() mode param must be either 0 (input), 1 " .
             "(output), 2 (PWM output) or 3 (GPIO CLOCK output)\n";
     }
 
-    $self->pin_mode($self->num, $mode);
+    # shell out to 'gpio' if in SYS mode
+
+    if ($self->pin_scheme == RPI_MODE_GPIO_SYS){
+        $mode = 'in'    if $mode == INPUT;
+        $mode = 'out'   if $mode == OUTPUT;
+        $mode = 'pwm'   if $mode == PWM_OUT;
+        $mode = 'clock' if $mode == GPIO_CLOCK;
+
+        my $num = $self->num;
+        `sudo gpio -g mode $num $mode`;
+    }
+    else {
+        $self->pin_mode($self->num, $mode);
+    }
 }
 sub read {
     my $state = $_[0]->read_pin($_[0]->num);
@@ -42,15 +62,46 @@ sub write {
     if ($value != 0 && $value != 1){
         die "Core::write_pin value must be 0 or 1\n";
     }
-    $self->write_pin($self->num, $value);
+    if ($self->pin_scheme == RPI_MODE_GPIO_SYS){
+        my $num = $self->num;
+        `sudo gpio -g write $num $value`;
+    }
+    else {
+        $self->write_pin($self->num, $value);
+    }
 }
 sub pull {
     my ($self, $direction) = @_;
+
     # 0 == down, 1 == up, 2 == off
+
     if ($direction != 0 && $direction != 1 && $direction != 2){
         die "Core::pull_up_down requires either 0, 1 or 2 for direction";
     }
-    $self->pull_up_down($self->num, $direction);
+
+    # shell out to 'gpio' if in SYS mode
+
+    if ($self->pin_scheme == RPI_MODE_GPIO_SYS){
+
+        if ($direction == PUD_DOWN){
+            $direction = 'down';
+        }
+        elsif ($direction == PUD_UP){
+            $direction = 'up';
+        }
+        else {
+            # PUD_OFF
+            $direction = 'tri';
+        }
+
+        my $num = $self->num;
+        $self->mode(INPUT);
+        `sudo gpio -g $num $direction`;
+    }
+    else {
+        $self->mode(INPUT);
+        $self->pull_up_down($self->num, $direction);
+    }
 }
 sub pwm {
     my ($self, $value) = @_;
@@ -137,8 +188,8 @@ Mandatory: The pin number to attach to.
 
 =head2 mode($mode)
 
-Puts the GPIO pin into either INPUT or OUTPUT mode. If C<$mode> is not sent in,
-we'll return the pin's current mode.
+Puts the GPIO pin into either INPUT, OUTPUT, PWM_OUT or GPIO_CLOCK mode. If
+C<$mode> is not sent in, we'll return the pin's current mode.
 
 Parameters:
 
@@ -164,7 +215,8 @@ Send in C<1> to turn the pin on, and C<0> to turn it off.
 
 =head2 pull($direction)
 
-Used to set the internal pull-up or pull-down resistor for a pin.
+Used to set the internal pull-up or pull-down resistor for a pin. Calling this
+method on a pin will automatically set the pin to C<INPUT> mode.
 
 Parameter:
 
@@ -195,7 +247,9 @@ Removes an interrupt from the pin, if set.
 =head2 pwm($value)
 
 Sets the level of the Pulse Width Modulation (PWM) of the pin. Dies if the
-pin's C<mode()> is not set to PWM (C<2>).
+pin's C<mode()> is not set to PWM (C<2>). Note that only physical pin 12
+(wiringPi pin 1, GPIO pin 18) is PWM hardware capable. See C<soft_pwm()> to
+use a software-based PWM implementation on all other pins.
 
 Parameter:
 
